/*
 * Copyright (C) 2009 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.dixheure;

import java.util.Calendar;
import java.util.List;

import com.dixheure.io.AlbumWrapper;
import com.dixheure.io.ThumbFetcher;
import com.dixheure.io.ThumbFetcherListener;
import com.dixheure.model.Thumbnailable;
import com.dixheure.model.Track;
import com.dixheure.shake.ShakeEventListener;
import com.google.gson.Gson;

import android.app.Activity;
import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.drawable.Drawable;
import android.hardware.Sensor;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.KeyEvent;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

/**
 * Alarm Clock alarm alert: pops visible indicator and plays alarm
 * tone. This activity is the full screen version which shows over the lock
 * screen with the wallpaper as the background.
 */
public class AlarmAlertFullScreen extends Activity {
	private static final String TRACK_RADIO_URL = "http://api.deezer.com/2.0/radio/%d/tracks";

	private static final String DEFAULT_SNOOZE = "10";
	private static final String DEFAULT_VOLUME_BEHAVIOR = "2";
	protected static final String SCREEN_OFF = "screen_off";

	protected Alarm mAlarm;
	private int mVolumeBehavior;

	private List<Track> mTrackList;
	private int mTrackIndex;

	private TextView mTitleTextView;
	private TextView mAlbumTextView;
	private TextView mArtistTextView;
	private ImageView mImageView;
	private Button	mSnoozeButton;
	private Button mDismissButton;
	private DigitalClock mDigitalClock;
	
	private SensorManager mSensorManager;
	private ShakeEventListener mSensorListener;

	private ThumbFetcher mThumbFetcher;
	
	// Receives the ALARM_KILLED action from the AlarmKlaxon.
	private BroadcastReceiver mReceiver = new BroadcastReceiver() {
		@Override
		public void onReceive(Context context, Intent intent) {
			Alarm alarm = intent.getParcelableExtra(Alarms.ALARM_INTENT_EXTRA);
			if (alarm != null && mAlarm.id == alarm.id) {
				dismiss(true);
			}
		}
	};
	
	private final Gson gson=new Gson();
	
	private String track;


	private BroadcastReceiver mTrackReceiver = new BroadcastReceiver() {
		@Override
		public void onReceive(Context context, Intent intent) {
			track=intent.getStringExtra(AlarmKlaxon.TRACK_EXTRA);
			launchNextTrack(gson.fromJson(track, Track.class));
		}
	};

	@Override
	protected void onCreate(Bundle icicle) {
		super.onCreate(icicle);
		
		mSensorManager = (SensorManager) getSystemService(Context.SENSOR_SERVICE);
		mSensorListener = new ShakeEventListener();   
	    mSensorListener.setOnShakeListener(new ShakeEventListener.OnShakeListener() {
	      public void onShake() {
	    	  snooze();
	      }
	    });
		
		mTrackIndex = -1;
//		int radioId = 12;
		mThumbFetcher = new ThumbFetcher(this);

		mAlarm = getIntent().getParcelableExtra(Alarms.ALARM_INTENT_EXTRA);
		final String vol = PreferenceManager.getDefaultSharedPreferences(this).getString(SettingsActivity.KEY_VOLUME_BEHAVIOR, DEFAULT_VOLUME_BEHAVIOR);
		mVolumeBehavior = Integer.parseInt(vol);
		requestWindowFeature(android.view.Window.FEATURE_NO_TITLE);

		final Window win = getWindow();
		win.addFlags(WindowManager.LayoutParams.FLAG_SHOW_WHEN_LOCKED | WindowManager.LayoutParams.FLAG_DISMISS_KEYGUARD);

		if (!getIntent().getBooleanExtra(SCREEN_OFF, false)) {
			win.addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON | WindowManager.LayoutParams.FLAG_TURN_SCREEN_ON);
		}

		updateLayout();
//		searchTrackByRadioId(radioId);
		
		launchNextTrack(null);
		registerReceiver(mReceiver, new IntentFilter(Alarms.ALARM_KILLED));

		registerReceiver(mTrackReceiver, new IntentFilter(AlarmKlaxon.TRACK_ACTION));
		
		
	}

	private void updateLayout() {
		setContentView(R.layout.alarm_alert);

		mTitleTextView = (TextView) findViewById(R.id.trackTitle);
		mArtistTextView = (TextView) findViewById(R.id.artistName);
		mAlbumTextView = (TextView) findViewById(R.id.albumName);
		mImageView = (ImageView) findViewById(R.id.trackCoverImage);

		mSnoozeButton = (Button) findViewById(R.id.snooze);
		mSnoozeButton.requestFocus();
		mSnoozeButton.setOnClickListener(new Button.OnClickListener() {
			public void onClick(View v) { snooze(); }
		});

		
        mDismissButton = (Button) findViewById(R.id.dismiss);
        mDismissButton.requestFocus();
        mDismissButton.setOnClickListener(new Button.OnClickListener() {
            public void onClick(View v) { dismiss(false); }
        });
		 
	}

//	private void searchTrackByRadioId(int trackId) {
//		AsyncHttpClient client = new AsyncHttpClient();
//		String url = String.format(TRACK_RADIO_URL, trackId);
//		client.get(url, new AsyncHttpResponseHandler() {
//			@Override
//			public void onSuccess(String response) {
//				try {
//					mTrackList = new ListDeezerDataReader<Track>(Track.class).readList(response);
//					launchNextTrack();
//				} catch (IllegalStateException exception) {}
//			}
//
//			@Override
//			public void onFailure(Throwable throwable, String str) {
//				super.onFailure(throwable, str);
//			}
//		});
//	}

//	private void launchNextTrack() {
//		mTrackIndex++;
//		final Track track = mTrackList.get(mTrackIndex);
//		mThumbFetcher.startFetchingThumbnails(track.getAlbum(), new ThumbFetcherListener() {
//			@Override
//			public void thumbLoaded(Thumbnailable thumbnailable) {
//				Drawable coverDrawable = mThumbFetcher.getThumbnail(track.getAlbum());
//				mImageView.setImageDrawable(coverDrawable);
//			}
//		});
//
//		mTitleTextView.setText(track.getTitle());
//		mArtistTextView.setText(track.getArtist().getName());
//		mAlbumTextView.setText(track.getAlbum().getTitle());
//		// TODO 
//	}

	private void launchNextTrack(final Track track) {

		if(track==null){
			mImageView.setImageDrawable(getResources().getDrawable(R.drawable.image_defaut));
			mTitleTextView.setText(getString(R.string.loading));
			mArtistTextView.setText("");
			mAlbumTextView.setText("");
		}
		else {

			mThumbFetcher.startFetchingThumbnails(new AlbumWrapper(track.getAlbum()), new ThumbFetcherListener() {
				@Override
				public void thumbLoaded(Thumbnailable thumbnailable) {
					Drawable coverDrawable = mThumbFetcher.getThumbnail(track.getAlbum());
					mImageView.setImageDrawable(coverDrawable);
				}
			});

			mTitleTextView.setText(track.getTitle());
			mArtistTextView.setText(track.getArtist().getName());
			mAlbumTextView.setText(track.getAlbum().getTitle());

		}
		// TODO 
	}

	private void snooze() {
		final String snooze = PreferenceManager.getDefaultSharedPreferences(this).getString(SettingsActivity.KEY_ALARM_SNOOZE, DEFAULT_SNOOZE);
		int snoozeMinutes = Integer.parseInt(snooze);

		final long snoozeTime = System.currentTimeMillis() + (1000 * 60 * snoozeMinutes);
		Alarms.saveSnoozeAlert(AlarmAlertFullScreen.this, mAlarm.id, snoozeTime);

		final Calendar c = Calendar.getInstance();
		c.setTimeInMillis(snoozeTime);

		String label = mAlarm.getLabelOrDefault(this);
		label = getString(R.string.alarm_notify_snooze_label, label);

		Intent cancelSnooze = new Intent(this, AlarmReceiver.class);
		cancelSnooze.setAction(Alarms.CANCEL_SNOOZE);
		cancelSnooze.putExtra(Alarms.ALARM_ID, mAlarm.id);
		PendingIntent broadcast = PendingIntent.getBroadcast(this, mAlarm.id, cancelSnooze, 0);
		NotificationManager nm = getNotificationManager();
		Notification n = new Notification(R.drawable.stat_notify_alarm, label, 0);
		n.setLatestEventInfo(this, label, getString(R.string.alarm_notify_snooze_text, Alarms.formatTime(this, c)), broadcast);
		n.flags |= Notification.FLAG_AUTO_CANCEL | Notification.FLAG_ONGOING_EVENT;
		nm.notify(mAlarm.id, n);

		String displayTime = getString(R.string.alarm_alert_snooze_set, snoozeMinutes);
		// Intentionally log the snooze time for debugging.
		Log.v(displayTime);

				// Display the snooze minutes in a toast.
		Toast.makeText(AlarmAlertFullScreen.this, displayTime, Toast.LENGTH_LONG).show();
		stopService(new Intent(Alarms.ALARM_ALERT_ACTION));
		finish();
	}

	private NotificationManager getNotificationManager() {
		return (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
	}

	// Dismiss the alarm.
	private void dismiss(boolean killed) {
		if (!killed) {
			
			Intent intent=new Intent(AlarmKlaxon.TRACK_WAKEUP);
			intent.putExtra(AlarmKlaxon.TRACK_EXTRA, track);
			
			sendBroadcast(intent);
			
			NotificationManager nm = getNotificationManager();
			nm.cancel(mAlarm.id);
			stopService(new Intent(Alarms.ALARM_ALERT_ACTION));
		}
		finish();
	}

	/**
	 * this is called when a second alarm is triggered while a
	 * previous alert window is still active.
	 */
	@Override
	protected void onNewIntent(Intent intent) {
		super.onNewIntent(intent);
		if (Log.LOGV) Log.v("AlarmAlert.OnNewIntent()");
		mAlarm = intent.getParcelableExtra(Alarms.ALARM_INTENT_EXTRA);
	}

	@Override
	protected void onStop() {
		super.onStop();
		if (!isFinishing()) {
			finish();
		}
	}

	@Override
	public void onDestroy() {
		super.onDestroy();
		unregisterReceiver(mReceiver);
		unregisterReceiver(mTrackReceiver);
	}

	@Override
	public boolean dispatchKeyEvent(KeyEvent event) {
		boolean up = event.getAction() == KeyEvent.ACTION_UP;
		switch (event.getKeyCode()) {
		case KeyEvent.KEYCODE_VOLUME_UP:
		case KeyEvent.KEYCODE_VOLUME_DOWN:
		case KeyEvent.KEYCODE_CAMERA:
		case KeyEvent.KEYCODE_FOCUS:
			if (up) {
				switch (mVolumeBehavior) {
				case 1: snooze(); break;
				case 2: dismiss(false); break;
				default: break;
				}
			}
			return true;
		default: break;
		}
		return super.dispatchKeyEvent(event);
	}

	@Override
	public void onBackPressed() { return; }
	
	@Override
	  protected void onResume() {
	    super.onResume();
	    mSensorManager.registerListener(mSensorListener,
	    								mSensorManager.getDefaultSensor(Sensor.TYPE_ACCELEROMETER),
	    								SensorManager.SENSOR_DELAY_UI);
	  }

	  @Override
	  protected void onPause() {
		  mSensorManager.unregisterListener(mSensorListener);
		  super.onStop();
	  }
}
