package com.dixheure;

import android.app.Activity;
import android.content.ClipData.Item;
import android.content.Context;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;
import android.widget.TimePicker;
import android.widget.TimePicker.OnTimeChangedListener;

import com.dixheure.Alarm.DaysOfWeek;
import com.dixheure.activity.radio.RadioListActivity;
import com.dixheure.histo.HistoryActivity;
import com.dixheure.io.ThumbFetcher;
import com.dixheure.io.ThumbFetcherListener;
import com.dixheure.model.Radio;
import com.dixheure.model.Thumbnailable;
import com.google.gson.Gson;

public class HomeActivity extends Activity{
	
	private long    radio_id;
	private String radio;
	
	private Alarm alarm;
	
	@Override
    protected void onCreate(Bundle icicle) {
		super.onCreate(icicle);
		setContentView(R.layout.home);
		TimePicker tp = (TimePicker)findViewById(R.id.timePicker);
        tp.setIs24HourView(true);
        
        alarm=Alarms.getAlarm(getContentResolver(), 1);
        if (alarm.enabled) {
        	
        }
        tp.setCurrentHour(alarm.hour);
        tp.setCurrentMinute(alarm.minutes);
        updateRadio(alarm.radio);
        
        Button styleButton = (Button) findViewById(R.id.styleButton);
        styleButton.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View arg0) {
				Intent intent=new Intent(HomeActivity.this, RadioListActivity.class);	
				startActivityForResult(intent, 12);
			}
		});
        
        tp.setOnTimeChangedListener(new OnTimeChangedListener() {
			
			@Override
			public void onTimeChanged(TimePicker view, int hour, int minutes) {
				Alarms.setAlarm(HomeActivity.this, alarm.id, alarm.enabled, hour, minutes, new DaysOfWeek(127), true, "Wake up", "0", alarm.radio_id, alarm.radio);
				alarm.hour = hour;
				alarm.minutes = minutes;
				if (alarm.enabled)
					popAlarmSetToast(HomeActivity.this, alarm.hour, alarm.minutes, alarm.daysOfWeek);
			}
		});
	}
	
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);

		if (resultCode != 0) {
			radio_id = data.getLongExtra(RadioListActivity.RESULT_RADIO_ID, 6);
			radio = data.getStringExtra(RadioListActivity.RESULT_RADIO_JSON);
			updateRadio(data.getStringExtra(RadioListActivity.RESULT_RADIO_JSON));
			Alarms.setAlarm(this, alarm.id, alarm.enabled, alarm.hour, alarm.minutes, new DaysOfWeek(127), true, "Wake up", "0", alarm.radio_id, radio);
		}
	}
	
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.main_menu, menu);
        return super.onCreateOptionsMenu(menu);
    }
    
	/**
	 * Display a toast that tells the user how long until the alarm
	 * goes off.  This helps prevent "am/pm" mistakes.
	 */
	public void popAlarmSetToast(Context context, int hour, int minute,
			Alarm.DaysOfWeek daysOfWeek) {
		popAlarmSetToast(context,
				Alarms.calculateAlarm(hour, minute, daysOfWeek)
				.getTimeInMillis());
	}

	private void popAlarmSetToast(Context context, long timeInMillis) {
		String toastText = formatToast(context, timeInMillis);
		TextView tv = (TextView) findViewById(R.id.notify);
		tv.setText(toastText);
	}

	/**
	 * format "Alarm set for 2 days 7 hours and 53 minutes from
	 * now"
	 */
	static String formatToast(Context context, long timeInMillis) {
		long delta = timeInMillis - System.currentTimeMillis();
		long hours = delta / (1000 * 60 * 60);
		long minutes = delta / (1000 * 60) % 60;
		long days = hours / 24;
		hours = hours % 24;

		String daySeq = (days == 0) ? "" :
			(days == 1) ? context.getString(R.string.day) :
				context.getString(R.string.days, Long.toString(days));

			String minSeq = (minutes == 0) ? "" :
				(minutes == 1) ? context.getString(R.string.minute) :
					context.getString(R.string.minutes, Long.toString(minutes));

				String hourSeq = (hours == 0) ? "" :
					(hours == 1) ? context.getString(R.string.hour) :
						context.getString(R.string.hours, Long.toString(hours));

					boolean dispDays = days > 0;
					boolean dispHour = hours > 0;
					boolean dispMinute = minutes > 0;

					int index = (dispDays ? 1 : 0) |
							(dispHour ? 2 : 0) |
							(dispMinute ? 4 : 0);

					String[] formats = context.getResources().getStringArray(R.array.alarm_set);
					return String.format(formats[index], daySeq, hourSeq, minSeq);
	}
	
	
	public boolean onMenuOpened(int featureId, Menu menu) {
		if (menu != null) {
			MenuItem item = menu.findItem(R.id.alarm_activate);
	    	
			if (alarm.enabled) {
	    		item.setTitle("Switch to alarm Off");
	    	} else {
	    		item.setTitle("Switch to alarm On");
	    	}
		}
		
		return super.onMenuOpened(featureId, menu);
	}
	
    
    public boolean onOptionsItemSelected(MenuItem item) {
    	TextView tv = (TextView) findViewById(R.id.notify);

        switch (item.getItemId()) {

            case R.id.menu_settings:
                startActivity(new Intent(this, SettingsActivity.class));
                return true;
                
            case R.id.menu_histo:
                startActivity(new Intent(this, HistoryActivity.class));
                return true;
            case R.id.alarm_activate:
            	if (alarm.enabled) {            		
            		alarm.enabled = false;            		
            		tv.setText("");
            	} else {
            		alarm.enabled = true;
            	}
            	
        		Alarms.setAlarm(HomeActivity.this, alarm.id, alarm.enabled, alarm.hour, alarm.minutes, new DaysOfWeek(127), true, "Wake up", "0", alarm.radio_id, alarm.radio);
            	return true;
        }
        

        return super.onOptionsItemSelected(item);
    }
   
    
	private void updateRadio (String radio){

		alarm.radio=radio;
		
		if(radio!=null && radio.length()>0){
			Gson gson = new Gson();
			final Radio r=gson.fromJson(radio, Radio.class);
			final Button styleButton = (Button) findViewById(R.id.styleButton);
			final ThumbFetcher mThumbFetcher = new ThumbFetcher(this);
			mThumbFetcher.startFetchingThumbnails(r, new ThumbFetcherListener() {
				@Override
				public void thumbLoaded(Thumbnailable thumbnailable) {
					Drawable coverDrawable = mThumbFetcher.getThumbnail(r);
					styleButton.setCompoundDrawablesWithIntrinsicBounds(coverDrawable, null, null, null);
					styleButton.setBackgroundResource(android.R.drawable.btn_default);
					styleButton.setVisibility(View.VISIBLE);
				}
			});			
						
			
			styleButton.setText(r.getTitle());
			
			styleButton.setBackgroundDrawable(null);
			
			
		}
		else {
			
//			mDeezerPref.setSummary(getString(R.string.no_radio));
		}
	}

}
