package com.dixheure.activity.radio;

import java.util.List;

import com.dixheure.R;
import com.dixheure.io.ThumbFetcher;
import com.dixheure.model.Radio;

import android.app.Activity;
import android.graphics.drawable.Drawable;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

public class RadioArrayAdapter extends ArrayAdapter<Radio> {
	protected static final int CELL_ID = R.layout.generic_cell;
	
	protected final List<Radio> 	mRadioList;
	protected final Activity		mActivity;
	protected final ThumbFetcher	mThumbFetcher;
	
	public RadioArrayAdapter(Activity		activity,
							 List<Radio>	radioList) {
		super(activity, CELL_ID, radioList);
		mRadioList = radioList;
		mActivity = activity;
		mThumbFetcher = new ThumbFetcher(activity);
	}
	
	@Override
    public View getView(int position, View convertView, ViewGroup parent) {
        View row = convertView;
        TrackHolder holder = null;
        
        if(row == null) {
            LayoutInflater inflater = mActivity.getLayoutInflater();
            row = inflater.inflate(CELL_ID, parent, false);
            
            row.setBackgroundResource(android.R.drawable.menuitem_background);
            
            holder = new TrackHolder();
            holder.titleTextView = (TextView) row.findViewById(R.id.titleCell);
            holder.descriptionTextView = (TextView) row.findViewById(R.id.subtitleCell);
            holder.pictureImageView = (ImageView) row.findViewById(R.id.thumbnailCell);
            
            row.setTag(holder);
        } else {
            holder = (TrackHolder)row.getTag();
        }
        final Radio radio = mRadioList.get(position);
        final Drawable thumbnailAlbumDrawable = mThumbFetcher.getThumbnail(radio);
        
        holder.titleTextView.setText(radio.getTitle());
        holder.descriptionTextView.setText(radio.getDescription());
        holder.pictureImageView.setImageDrawable(thumbnailAlbumDrawable);
        
        return row;
    }
	
	static class TrackHolder {
		public TextView	titleTextView;
		public TextView	descriptionTextView;
		public ImageView pictureImageView;
	}

}
