package com.dixheure.activity.radio;
import java.util.ArrayList;
import java.util.List;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.dixheure.DeezerBaseActivity;
import com.dixheure.R;
import com.dixheure.io.ListDeezerDataReader;
import com.dixheure.io.ThumbFetcher;
import com.dixheure.io.ThumbFetcherListener;
import com.dixheure.model.Radio;
import com.dixheure.model.Thumbnailable;
import com.google.gson.Gson;
import com.loopj.android.http.AsyncHttpClient;
import com.loopj.android.http.AsyncHttpResponseHandler;

public class RadioListActivity extends DeezerBaseActivity {
	public static final String RESULT_RADIO_ID = "result.radio.id";
	
	public static final String RESULT_RADIO_JSON = "result.radio.json";
	
	private static final String URL = "http://api.deezer.com/2.0/radio";
	
	private ProgressBar mProgressBar;
	private Button mEmptyButton;
	private ListView mListView;
	
	private List<Radio> radioList;
	private ArrayAdapter<Radio> arrayAdapter;
	private OnItemClickListener onRadioClickListener;
	private ThumbFetcher thumbFetcher;
		
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.radio_list);
		radioList = new ArrayList<Radio>();
		thumbFetcher = new ThumbFetcher(this);
		arrayAdapter = new RadioArrayAdapter(this, radioList);
		onRadioClickListener = new RadioOnclickListener();
		
		mProgressBar = (ProgressBar) findViewById(R.id.radio_spinner);
		mListView = (ListView) findViewById(R.id.radio_listing);
		
		mEmptyButton = (Button) findViewById(R.id.radio_empty);
		mEmptyButton.setText(getResources().getString(R.string.empty_radio));
		mEmptyButton.setVisibility(View.GONE);
		
		mListView.setAdapter(arrayAdapter);
		mListView.setOnItemClickListener(onRadioClickListener);
		searchRadio();
	}
	
	private void searchRadio() {
		AsyncHttpClient client = new AsyncHttpClient();
		client.get(URL, new AsyncHttpResponseHandler() {
		    @Override
		    public void onSuccess(String response) {
		    	List<Radio> radioList = null;
				try {
					radioList = new ListDeezerDataReader<Radio>(Radio.class).readList(response);
					radioList = radioList.subList(28, radioList.size() - 1);
					searchComplete(radioList);
				} catch (IllegalStateException exception) {
					handleError(exception);
				}
				onDidLoad();
		    }
		    
		    @Override
		    public void onFailure(Throwable throwable, String str) {
		    	super.onFailure(throwable, str);
		    	onDidLoad();
		    }
		});
	}
	
	private void onDidLoad() {
		mProgressBar.setVisibility(View.INVISIBLE);
	}
	
	private void searchComplete(List<Radio> listReceived) {
		radioList.clear();
		try {
			radioList.addAll(listReceived);
			if(radioList.isEmpty()) {
				Toast.makeText(RadioListActivity.this, "Aucun resultat", Toast.LENGTH_LONG);
			}else {
				thumbFetcher.startFetchingThumbnails(radioList, new ThumbnailFetcherHandler());
			}
			arrayAdapter.notifyDataSetChanged();
		} catch (Exception exception) {
			handleError(exception);
		}
	}

	private class ThumbnailFetcherHandler implements ThumbFetcherListener {
		@Override
		public void thumbLoaded(Thumbnailable thumbnailable) {
			arrayAdapter.notifyDataSetChanged();
		}
	}
	
	private class RadioOnclickListener implements OnItemClickListener {
		@Override
		public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
			final Radio radio =  radioList.get(position);
			Gson gson = new Gson();
			
			
			final Intent resultIntent = new Intent();
			resultIntent.putExtra(RESULT_RADIO_ID, radio.getId());
			resultIntent.putExtra(RESULT_RADIO_JSON, gson.toJson(radio));
	
			setResult(Activity.RESULT_OK, resultIntent);
			finish();
		}
	}
}
