package com.dixheure.histo;

import android.app.ListActivity;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.drawable.Drawable;
import android.os.Bundle;

import android.text.format.DateUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.CursorAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.dixheure.R;
import com.dixheure.io.ThumbFetcher;
import com.dixheure.io.ThumbFetcherListener;
import com.dixheure.model.Thumbnailable;
import com.dixheure.model.Track;
import com.google.gson.Gson;

public class HistoryActivity extends ListActivity implements OnItemClickListener{

	
	private Gson gson=new Gson();

	private ThumbFetcher mThumbFetcher;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setContentView(R.layout.histo);

		final LayoutInflater inflater=LayoutInflater.from(this);

		mThumbFetcher = new ThumbFetcher(this);

		getListView().setOnItemClickListener(this);

		setListAdapter(new CursorAdapter(this,Histories.getHisto(getContentResolver()),true) {

			@Override
			public View newView(Context context, Cursor cursor, ViewGroup parent) {
				return inflater.inflate(R.layout.histo_item, parent, false);
			}

			@Override
			public void bindView(View view, Context context, Cursor cursor) {

				String t=cursor.getString(History.Columns.HISTO_TRACK_INDEX);

				final Track track=gson.fromJson(t, Track.class);

				TextView title=(TextView)view.findViewById(R.id.titleCell);
				title.setText(track.getTitle());

				TextView subtitle=(TextView)view.findViewById(R.id.subtitleCell);
				subtitle.setText(track.getArtist().getName());
				
				
				long date=cursor.getLong(History.Columns.HISTO_DATE_INDEX);
				
				TextView dateView=(TextView)view.findViewById(R.id.date);
				dateView.setText(DateUtils.getRelativeTimeSpanString(context,date, true));

				
				final ImageView mImageView=(ImageView)view.findViewById(R.id.thumbnailCell);

				mThumbFetcher.startFetchingThumbnails(track.getAlbum(), new ThumbFetcherListener() {
					@Override
					public void thumbLoaded(Thumbnailable thumbnailable) {
						Drawable coverDrawable = mThumbFetcher.getThumbnail(track.getAlbum());
						mImageView.setImageDrawable(coverDrawable);
						mImageView.setVisibility(View.VISIBLE);
					}
				});
				
				final ImageView snoozView=(ImageView)view.findViewById(R.id.snoozed);
				
				System.out.println(cursor.getInt(cursor.getColumnIndex(History.Columns.SNOOZED)));
				
				if(cursor.getInt(History.Columns.HISTO_SNOOZED_INDEX)==0){
					snoozView.setImageResource(R.drawable.snoozer_mecontent);
				}
				else {
					snoozView.setImageResource(R.drawable.snoozer_content);
				}
				
				

			}
		});



	}

	@Override
	public void onItemClick(AdapterView<?> list, View v, int position, long id) {
		
		
		Cursor cursor=Histories.getHisto(getContentResolver(), id);
		if(cursor!=null){
			
			String t=cursor.getString(History.Columns.HISTO_TRACK_INDEX);
			final Track track=gson.fromJson(t, Track.class);
			
			if(track!=null){
				Intent intent = new Intent(Intent.ACTION_SEND);
				intent.setType("text/plain");
				intent.putExtra(Intent.EXTRA_TEXT, getString(R.string.share, track.getTitle()+", "+track.getArtist().getName(),track.getLink()));
				startActivity(Intent.createChooser(intent, "Dialog title text"));	
			}
		}
	
	}



}
