package com.dixheure.model;

/**
 * A playlist in the simple Deezer API.
 * This class will be serialized/deserialized using gson json API in  this format : 
 * <pre>
    {
      "id": "64087426",
      "title": "classik",
      "link": "http://www.deezer.com/music/playlist/64087426",
      "picture": "http://api.deezer.com/2.0/playlist/64087426/image",
      "creator": {
        "id": "17861542"
      },
      "type": "playlist"
    }
 * </pre>
 * @author Deezer
 */
public class Playlist implements Thumbnailable {
	/** Id of the playlist. */
	private long id;
	/** Title of the playlist. */
	private String title;
	/** The link on Deezer of the playlist. */
	private String link;
	/** Thumbnail url of the playlist. */
	private String picture;
	
	private long duration;
	
	@Override
	public String getThumbnailUrl() {
		return picture;
	}//met
	
	public long getId() {
		return id;
	}//met
	
	public void setId(long id) {
		this.id = id;
	}//met
	
	public String getTitle() {
		return title;
	}//met
	
	public void setTitle(String title) {
		this.title = title;
	}//met
	
	public String getLink() {
		return link;
	}//met
	
	public void setLink(String link) {
		this.link = link;
	}//met
	
	public String getPicture() {
		return picture;
	}//met
	
	public void setPicture(String picture) {
		this.picture = picture;
	}//met
	
	public long getDuration() {
		return duration;
	}
	
	public void setDuration(long value) {
		duration = value;
	}
	
	public String getStringDuration() {
		if (duration == 0) return "";
		
		final StringBuilder builderResult = new StringBuilder();
		final long hours = duration / 3600;
		final long mins = (duration / 60) % 60;
		final long seconds = (duration % 60);
		
		if (hours > 0) {
			builderResult.append(hours);
			if (hours > 1) {
				builderResult.append("hours ");
			} else {
				builderResult.append("hour ");
			}
		}
		
		builderResult.append(mins);
		if (mins > 1) {
			builderResult.append("mins ");
		} else {
			builderResult.append("min ");
		}
		
		if (seconds > 0) {
			builderResult.append(seconds);
			builderResult.append("sec");
		}
		
		return builderResult.toString();
	}
	
}//class
